@@ -78,7 +78,7 @@ d3.geom.quadtree = function(points, x1, y1, x2, y2) {
           // point we are adding, we leave the point associated with the
           // internal node while adding the new point to a child node. This
           // avoids infinite recursion.
-          if ((abs(nx - x) + abs(ny - y)) < .01) {
+          if ((abs(nx - x) + abs(ny - y)) < 0.01) {
             insertChild(n, d, x, y, x1, y1, x2, y2);
           } else {
             var nPoint = n.point;
@@ -98,8 +98,8 @@ d3.geom.quadtree = function(points, x1, y1, x2, y2) {
     // n. The bounds are defined by [x1, x2] and [y1, y2].
     function insertChild(n, d, x, y, x1, y1, x2, y2) {
       // Compute the split point, and the quadrant in which to insert p.
-      var xm = (x1 + x2) * .5,
-          ym = (y1 + y2) * .5,
+      var xm = (x1 + x2) * 0.5,
+          ym = (y1 + y2) * 0.5,
           right = x >= xm,
           below = y >= ym,
           i = below << 1 | right;
@@ -188,8 +188,8 @@ function d3_geom_quadtreeNode() {
 
 function d3_geom_quadtreeVisit(f, node, x1, y1, x2, y2) {
   if (!f(node, x1, y1, x2, y2)) {
-    var sx = (x1 + x2) * .5,
-        sy = (y1 + y2) * .5,
+    var sx = (x1 + x2) * 0.5,
+        sy = (y1 + y2) * 0.5,
         children = node.nodes;
     if (children[0]) d3_geom_quadtreeVisit(f, children[0], x1, y1, sx, sy);
     if (children[1]) d3_geom_quadtreeVisit(f, children[1], sx, y1, x2, sy);
@@ -210,8 +210,8 @@ function d3_geom_quadtreeFind(root, x, y, x0, y0, x3, y3) {
     // visit this point
     if (point = node.point) {
       var point,
-          dx = x - point[0],
-          dy = y - point[1],
+          dx = x - node.x,
+          dy = y - node.y,
           distance2 = dx * dx + dy * dy;
       if (distance2 < minDistance2) {
         var distance = Math.sqrt(minDistance2 = distance2);
@@ -223,8 +223,8 @@ function d3_geom_quadtreeFind(root, x, y, x0, y0, x3, y3) {
 
     // bisect the current node
     var children = node.nodes,
-        xm = (x1 + x2) * .5,
-        ym = (y1 + y2) * .5,
+        xm = (x1 + x2) * 0.5,
+        ym = (y1 + y2) * 0.5,
         right = x >= xm,
         below = y >= ym;
 
