@@ -8,11 +8,11 @@ suite.addBatch({
   "interpolateNumber": {
     topic: load("interpolate/number").expression("d3.interpolateNumber"),
     "interpolates numbers": function(interpolate) {
-      assert.strictEqual(interpolate(2, 12)(.4), 6);
-      assert.strictEqual(interpolate(2, 12)(.6), 8);
+      assert.strictEqual(interpolate(2, 12)(0.25), 4.5);
+      assert.strictEqual(interpolate(2, 12)(0.75), 9.5);
     },
     "coerces strings to numbers": function(interpolate) {
-      assert.strictEqual(interpolate("2", "12")(.4), 6);
+      assert.strictEqual(interpolate("2", "12")(0.25), 4.5);
     }
   }
 });
