@@ -12,26 +12,26 @@ suite.addBatch({
       "defaults to [0, 1]": function(d3) {
         var x = d3.scale.linear();
         assert.deepEqual(x.domain(), [0, 1]);
-        assert.inDelta(x(.5), .5, 1e-6);
+        assert.inDelta(x(0.5), 0.5, 1e-6);
       },
       "coerces domain values to numbers": function(d3) {
         var x = d3.scale.linear().domain([new Date(1990, 0, 1), new Date(1991, 0, 1)]);
         assert.equal(typeof x.domain()[0], "number");
         assert.equal(typeof x.domain()[1], "number");
-        assert.inDelta(x(new Date(1989, 09, 20)), -.2, 1e-2);
+        assert.inDelta(x(new Date(1989, 09, 20)), -0.2, 1e-2);
         assert.inDelta(x(new Date(1990, 00, 01)), 0, 1e-2);
-        assert.inDelta(x(new Date(1990, 02, 15)), .2, 1e-2);
-        assert.inDelta(x(new Date(1990, 04, 27)), .4, 1e-2);
+        assert.inDelta(x(new Date(1990, 02, 15)), 0.2, 1e-2);
+        assert.inDelta(x(new Date(1990, 04, 27)), 0.4, 1e-2);
         assert.inDelta(x(new Date(1991, 00, 01)), 1, 1e-2);
         assert.inDelta(x(new Date(1991, 02, 15)), 1.2, 1e-2);
         var x = d3.scale.linear().domain(["0", "1"]);
         assert.equal(typeof x.domain()[0], "number");
         assert.equal(typeof x.domain()[1], "number");
-        assert.inDelta(x(.5), .5, 1e-6);
+        assert.inDelta(x(0.5), 0.5, 1e-6);
         var x = d3.scale.linear().domain([new Number(0), new Number(1)]);
         assert.equal(typeof x.domain()[0], "number");
         assert.equal(typeof x.domain()[1], "number");
-        assert.inDelta(x(.5), .5, 1e-6);
+        assert.inDelta(x(0.5), 0.5, 1e-6);
       },
       "can specify a polylinear domain and range": function(d3) {
         var x = d3.scale.linear().domain([-10, 0, 100]).range(["red", "white", "green"]);
@@ -59,7 +59,7 @@ suite.addBatch({
       "defaults to [0, 1]": function(d3) {
         var x = d3.scale.linear();
         assert.deepEqual(x.range(), [0, 1]);
-        assert.inDelta(x.invert(.5), .5, 1e-6);
+        assert.inDelta(x.invert(0.5), 0.5, 1e-6);
       },
       "does not coerce range to numbers": function(d3) {
         var x = d3.scale.linear().range(["0", "2"]);
@@ -68,21 +68,21 @@ suite.addBatch({
       },
       "can specify range values as colors": function(d3) {
         var x = d3.scale.linear().range(["red", "blue"]);
-        assert.equal(x(.5), "#800080");
+        assert.equal(x(0.5), "#800080");
         var x = d3.scale.linear().range(["#ff0000", "#0000ff"]);
-        assert.equal(x(.5), "#800080");
+        assert.equal(x(0.5), "#800080");
         var x = d3.scale.linear().range(["#f00", "#00f"]);
-        assert.equal(x(.5), "#800080");
-        var x = d3.scale.linear().range([d3.rgb(255,0,0), d3.hsl(240,1,.5)]);
-        assert.equal(x(.5), "#800080");
+        assert.equal(x(0.5), "#800080");
+        var x = d3.scale.linear().range([d3.rgb(255,0,0), d3.hsl(240,1,0.5)]);
+        assert.equal(x(0.5), "#800080");
         var x = d3.scale.linear().range(["hsl(0,100%,50%)", "hsl(240,100%,50%)"]);
-        assert.equal(x(.5), "#800080");
+        assert.equal(x(0.5), "#800080");
       },
       "can specify range values as arrays or objects": function(d3) {
         var x = d3.scale.linear().range([{color: "red"}, {color: "blue"}]);
-        assert.deepEqual(x(.5), {color: "#800080"});
+        assert.deepEqual(x(0.5), {color: "#800080"});
         var x = d3.scale.linear().range([["red"], ["blue"]]);
-        assert.deepEqual(x(.5), ["#800080"]);
+        assert.deepEqual(x(0.5), ["#800080"]);
       }
     },
 
@@ -90,11 +90,11 @@ suite.addBatch({
       "defaults to d3.interpolate": function(d3) {
         var x = d3.scale.linear().range(["red", "blue"]);
         assert.equal(x.interpolate(), d3.interpolate);
-        assert.equal(x(.5), "#800080");
+        assert.equal(x(0.5), "#800080");
       },
       "can specify a custom interpolator": function(d3) {
         var x = d3.scale.linear().range(["red", "blue"]).interpolate(d3.interpolateHsl);
-        assert.equal(x(.5), "#ff00ff");
+        assert.equal(x(0.5), "#ff00ff");
       }
     },
 
@@ -102,36 +102,36 @@ suite.addBatch({
       "defaults to false": function(d3) {
         var x = d3.scale.linear();
         assert.isFalse(x.clamp());
-        assert.inDelta(x(-.5), -.5, 1e-6);
+        assert.inDelta(x(-0.5), -0.5, 1e-6);
         assert.inDelta(x(1.5), 1.5, 1e-6);
       },
       "can clamp to the domain": function(d3) {
         var x = d3.scale.linear().clamp(true);
-        assert.inDelta(x(-.5), 0, 1e-6);
-        assert.inDelta(x(.5), .5, 1e-6);
+        assert.inDelta(x(-0.5), 0, 1e-6);
+        assert.inDelta(x(0.5), 0.5, 1e-6);
         assert.inDelta(x(1.5), 1, 1e-6);
         var x = d3.scale.linear().domain([1, 0]).clamp(true);
-        assert.inDelta(x(-.5), 1, 1e-6);
-        assert.inDelta(x(.5), .5, 1e-6);
+        assert.inDelta(x(-0.5), 1, 1e-6);
+        assert.inDelta(x(0.5), 0.5, 1e-6);
         assert.inDelta(x(1.5), 0, 1e-6);
       },
       "can clamp to the range": function(d3) {
         var x = d3.scale.linear().clamp(true);
-        assert.inDelta(x.invert(-.5), 0, 1e-6);
-        assert.inDelta(x.invert(.5), .5, 1e-6);
+        assert.inDelta(x.invert(-0.5), 0, 1e-6);
+        assert.inDelta(x.invert(0.5), 0.5, 1e-6);
         assert.inDelta(x.invert(1.5), 1, 1e-6);
         var x = d3.scale.linear().range([1, 0]).clamp(true);
-        assert.inDelta(x.invert(-.5), 1, 1e-6);
-        assert.inDelta(x.invert(.5), .5, 1e-6);
+        assert.inDelta(x.invert(-0.5), 1, 1e-6);
+        assert.inDelta(x.invert(0.5), 0.5, 1e-6);
         assert.inDelta(x.invert(1.5), 0, 1e-6);
       }
     },
 
     "maps a number to a number": function(d3) {
       var x = d3.scale.linear().domain([1, 2]);
-      assert.inDelta(x(.5), -.5, 1e-6);
+      assert.inDelta(x(0.5), -0.5, 1e-6);
       assert.inDelta(x(1), 0, 1e-6);
-      assert.inDelta(x(1.5), .5, 1e-6);
+      assert.inDelta(x(1.5), 0.5, 1e-6);
       assert.inDelta(x(2), 1, 1e-6);
       assert.inDelta(x(2.5), 1.5, 1e-6);
     },
@@ -139,19 +139,22 @@ suite.addBatch({
     "invert": {
       "maps a number to a number": function(d3) {
         var x = d3.scale.linear().range([1, 2]);
-        assert.inDelta(x.invert(.5), -.5, 1e-6);
+        assert.inDelta(x.invert(0.5), -0.5, 1e-6);
         assert.inDelta(x.invert(1), 0, 1e-6);
-        assert.inDelta(x.invert(1.5), .5, 1e-6);
+        assert.inDelta(x.invert(1.5), 0.5, 1e-6);
         assert.inDelta(x.invert(2), 1, 1e-6);
         assert.inDelta(x.invert(2.5), 1.5, 1e-6);
       },
       "coerces range value to numbers": function(d3) {
         var x = d3.scale.linear().range(["0", "2"]);
-        assert.inDelta(x.invert("1"), .5, 1e-6);
+        assert.inDelta(x.invert("1"), 0.5, 1e-6);
         var x = d3.scale.linear().range([new Date(1990, 0, 1), new Date(1991, 0, 1)]);
-        assert.inDelta(x.invert(new Date(1990, 6, 2, 13)), .5, 1e-6);
+        assert.inDelta(x.invert(new Date(1990, 6, 2, 13)), 0.5, 1e-6);
         var x = d3.scale.linear().range(["#000", "#fff"]);
         assert.isNaN(x.invert("#999"));
+        var x = d3.scale.linear().range([0, "#fff"]);
+        assert.isNaN(x.invert("#999"));
+        assert.isNaN(x.invert(1));
       },
       "can invert a polylinear descending domain": function(d3) {
         var x = d3.scale.linear().domain([4, 2, 1]).range([1, 2, 4]);
@@ -173,17 +176,17 @@ suite.addBatch({
       "generates ticks of varying degree": function(d3) {
         var x = d3.scale.linear();
         assert.deepEqual(x.ticks(1).map(x.tickFormat(1)), [0, 1]);
-        assert.deepEqual(x.ticks(2).map(x.tickFormat(2)), [0, .5, 1]);
-        assert.deepEqual(x.ticks(5).map(x.tickFormat(5)), [0, .2, .4, .6, .8, 1]);
-        assert.deepEqual(x.ticks(10).map(x.tickFormat(10)), [0, .1, .2, .3, .4, .5, .6, .7, .8, .9, 1]);
+        assert.deepEqual(x.ticks(2).map(x.tickFormat(2)), [0, 0.5, 1]);
+        assert.deepEqual(x.ticks(5).map(x.tickFormat(5)), [0, 0.2, 0.4, 0.6, 0.8, 1]);
+        assert.deepEqual(x.ticks(10).map(x.tickFormat(10)), [0, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1]);
         var x = d3.scale.linear().domain([1, 0]);
         assert.deepEqual(x.ticks(1).map(x.tickFormat(1)), [0, 1]);
-        assert.deepEqual(x.ticks(2).map(x.tickFormat(2)), [0, .5, 1]);
-        assert.deepEqual(x.ticks(5).map(x.tickFormat(5)), [0, .2, .4, .6, .8, 1]);
-        assert.deepEqual(x.ticks(10).map(x.tickFormat(10)), [0, .1, .2, .3, .4, .5, .6, .7, .8, .9, 1]);
+        assert.deepEqual(x.ticks(2).map(x.tickFormat(2)), [0, 0.5, 1]);
+        assert.deepEqual(x.ticks(5).map(x.tickFormat(5)), [0, 0.2, 0.4, 0.6, 0.8, 1]);
+        assert.deepEqual(x.ticks(10).map(x.tickFormat(10)), [0, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1]);
       },
       "formats ticks with the appropriate precision": function(d3) {
-        var x = d3.scale.linear().domain([.123456789, 1.23456789]);
+        var x = d3.scale.linear().domain([0.123456789, 1.23456789]);
         assert.strictEqual(x.tickFormat(1)(x.ticks(1)[0]), "1");
         assert.strictEqual(x.tickFormat(2)(x.ticks(2)[0]), "0.5");
         assert.strictEqual(x.tickFormat(4)(x.ticks(4)[0]), "0.2");
@@ -246,24 +249,26 @@ suite.addBatch({
         assert.deepEqual(x.domain(), [1, 11]);
         var x = d3.scale.linear().domain([10.9, 1.1]).nice();
         assert.deepEqual(x.domain(), [11, 1]);
-        var x = d3.scale.linear().domain([.7, 11.001]).nice();
+        var x = d3.scale.linear().domain([0.7, 11.001]).nice();
         assert.deepEqual(x.domain(), [0, 12]);
         var x = d3.scale.linear().domain([123.1, 6.7]).nice();
         assert.deepEqual(x.domain(), [130, 0]);
-        var x = d3.scale.linear().domain([0, .49]).nice();
-        assert.deepEqual(x.domain(), [0, .5]);
+        var x = d3.scale.linear().domain([0, 0.49]).nice();
+        assert.deepEqual(x.domain(), [0, 0.5]);
+        var x = d3.scale.linear().domain([-0.1, 51.1]).nice(8);
+        assert.deepEqual(x.domain(), [-10, 60]);
       },
       "has no effect on degenerate domains": function(d3) {
         var x = d3.scale.linear().domain([0, 0]).nice();
         assert.deepEqual(x.domain(), [0, 0]);
-        var x = d3.scale.linear().domain([.5, .5]).nice();
-        assert.deepEqual(x.domain(), [.5, .5]);
+        var x = d3.scale.linear().domain([0.5, 0.5]).nice();
+        assert.deepEqual(x.domain(), [0.5, 0.5]);
       },
       "nicing a polylinear domain only affects the extent": function(d3) {
         var x = d3.scale.linear().domain([1.1, 1, 2, 3, 10.9]).nice();
         assert.deepEqual(x.domain(), [1, 1, 2, 3, 11]);
-        var x = d3.scale.linear().domain([123.1, 1, 2, 3, -.9]).nice();
-        assert.deepEqual(x.domain(), [130, 1, 2, 3, -10]);
+        var x = d3.scale.linear().domain([123.1, 1, 2, 3, -0.9]).nice();
+        assert.deepEqual(x.domain(), [140, 1, 2, 3, -20]);
       },
       "accepts a tick count to control nicing step": function(d3) {
         var x = d3.scale.linear().domain([12, 87]).nice(5);
